===========
jaffle stop
===========

Stops the running Jaffle process.
If it is not running, removes runtime files if they exist.

Usage
=====

.. code-block:: sh

    jaffle stop [options]

Options
=======

- **--runtime-dir=<Unicode>** (BaseJaffleCommand.runtime_dir)

    Default: '.jaffle'

    Runtime directory path.
